@@ -1,4 +1,4 @@
-/* Copyright 2007, 2008 Matthew Barnes
+/* Copyright 2007-2009 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -140,6 +140,8 @@ game_store_constructor (GType type,
         types[column++] = G_TYPE_BOOLEAN;    /* COLUMN_INPUT_SERVICE */
         types[column++] = G_TYPE_BOOLEAN;    /* COLUMN_INPUT_TILT */
         types[column++] = G_TYPE_INT;        /* COLUMN_INPUT_PLAYERS */
+        types[column++] = G_TYPE_INT;        /* COLUMN_INPUT_PLAYERS_ALT */
+        types[column++] = G_TYPE_INT;        /* COLUMN_INPUT_PLAYERS_SIM */
         types[column++] = G_TYPE_INT;        /* COLUMN_INPUT_BUTTONS */
         types[column++] = G_TYPE_INT;        /* COLUMN_INPUT_COINS */
         types[column++] = G_TYPE_STRING;     /* COLUMN_DRIVER_STATUS */
@@ -249,7 +251,7 @@ gva_game_store_new (void)
 /**
  * gva_game_store_new_from_query:
  * @sql: an SQL query
- * @error: return locations for a #GError, or %NULL
+ * @error: return location for a #GError, or %NULL
  *
  * This may be the most powerful function in
  * <emphasis>GNOME Video Arcade</emphasis>.
