@@ -1,4 +1,4 @@
-/* Copyright 2007, 2008 Matthew Barnes
+/* Copyright 2007-2009 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -28,6 +28,7 @@
 #include "gva-game-store.h"
 #include "gva-main.h"
 #include "gva-mame.h"
+#include "gva-mute-button.h"
 #include "gva-play-back.h"
 #include "gva-preferences.h"
 #include "gva-process.h"
@@ -47,7 +48,7 @@ static const gchar *authors[] =
         NULL
 };
 static const gchar *copyright =
-"Copyright \xC2\xA9 2007, 2008 Matthew Barnes";
+"Copyright \xC2\xA9 2007-2009 Matthew Barnes";
 static const gchar *license =
 "GNOME Video Arcade is free software; you can redistribute it "
 "and/or modify it under the terms of the GNU General Public License "
@@ -63,7 +64,9 @@ static const gchar *license =
 "along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 
 static void
-record_game_exited (GvaProcess *process, gint status, gchar *inpname)
+record_game_exited (GvaProcess *process,
+                    gint status,
+                    gchar *inpname)
 {
         if (process->error == NULL)
                 gva_play_back_show (inpname);
@@ -833,6 +836,7 @@ ui_init (void)
         {
                 REGISTER_WIDGET (GTK_TYPE_LINK_BUTTON);
                 REGISTER_WIDGET (GVA_TYPE_COLUMN_MANAGER);
+                REGISTER_WIDGET (GVA_TYPE_MUTE_BUTTON);
 
                 glade_provide ("gva");
                 xml = glade_xml_new (filename, NULL, NULL);
@@ -1003,7 +1007,7 @@ gva_ui_add_column_actions (GtkTreeView *view)
 
                 gtk_ui_manager_add_ui (
                         manager, merge_id,
-                        "/game-popup/add-column",
+                        "/column-popup/add-column",
                         action_name, action_name,
                         GTK_UI_MANAGER_AUTO, FALSE);
 
