@@ -1,4 +1,4 @@
-/* Copyright 2007 Matthew Barnes
+/* Copyright 2007 - 2009 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -18,6 +18,7 @@
 
 #include "gva-common.h"
 
+#include <errno.h>
 #include <libintl.h>
 #include <locale.h>
 #include <stdlib.h>
@@ -28,17 +29,23 @@
 #endif
 
 #include "gva-audit.h"
+#include "gva-categories.h"
 #include "gva-db.h"
 #include "gva-error.h"
 #include "gva-history.h"
 #include "gva-main.h"
 #include "gva-mame.h"
+#include "gva-nplayers.h"
 #include "gva-play-back.h"
 #include "gva-preferences.h"
 #include "gva-properties.h"
-#include "gva-search.h"
 #include "gva-tree-view.h"
 #include "gva-ui.h"
+#include "gva-util.h"
+
+#define SQL_COUNT_ROMS \
+        "SELECT count(*) FROM game WHERE " \
+        "romset NOTNULL AND romset != 'not found'"
 
 static GOptionEntry entries[] =
 {
@@ -63,33 +70,113 @@ static GOptionEntry entries[] =
 };
 
 static void
-start (void)
+warn_if_no_roms (void)
 {
-        gchar *mame_version;
-        guint context_id;
+        const gchar *sql = SQL_COUNT_ROMS;
+        GtkWidget *dialog;
+        gchar **result;
+        glong n_roms;
         GError *error = NULL;
 
-        context_id = gva_main_statusbar_get_context_id (G_STRFUNC);
-        mame_version = gva_mame_get_version (&error);
-        gva_error_handle (&error);
-
-        if (mame_version != NULL)
+        if (!gva_db_get_table (sql, &result, NULL, NULL, &error))
         {
-                gva_main_statusbar_push (context_id, "%s", mame_version);
-                g_free (mame_version);
+                gva_error_handle (&error);
+                return;
         }
 
+        errno = 0;
+        g_return_if_fail (g_strv_length (result) > 1);
+        n_roms = strtol (result[1], NULL, 10);
+        g_strfreev (result);
+
+        if (errno != 0)
+        {
+                g_warning ("%s", g_strerror (errno));
+                return;
+        }
+
+        if (n_roms > 0)
+                return;
+
+        dialog = gtk_message_dialog_new_with_markup (
+                GTK_WINDOW (GVA_WIDGET_MAIN_WINDOW),
+                GTK_DIALOG_DESTROY_WITH_PARENT,
+                GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE,
+                "<big><b>%s</b></big>",
+                _("No ROM files found"));
+
+#if GTK_CHECK_VERSION(2,14,0) || defined WITH_GNOME
+        gtk_message_dialog_format_secondary_markup (
+                GTK_MESSAGE_DIALOG (dialog),
+                _("GNOME Video Arcade was unable to locate any ROM files. "
+                  "It could be that MAME is misconfigured or that no ROM "
+                  "files are installed. Click <b>Help</b> for more details "
+                  "and troubleshooting tips."));
+
+        gtk_dialog_add_button (
+                GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
+#else
+        gtk_message_dialog_format_secondary_markup (
+                GTK_MESSAGE_DIALOG (dialog),
+                _("GNOME Video Arcade was unable to locate any ROM files. "
+                  "It could be that MAME is misconfigured or no ROM files "
+                  "are installed. Consult the user documentation for more "
+                  "details and troubleshooting tips."));
+#endif
+
+        if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_HELP)
+                gva_help_display (GTK_WINDOW (dialog), "troubleshooting");
+
+        gtk_widget_destroy (dialog);
+}
+
+static void
+start (void)
+{
+        GError *error = NULL;
+
         if (gva_db_needs_rebuilt ())
         {
-                gboolean success;
+                gva_main_progress_bar_show ();
 
-                success = gva_main_build_database (&error);
-                gva_error_handle (&error);
-
-                if (!success)
+                if (!gva_main_build_database (&error))
+                {
+                        gva_error_handle (&error);
                         return;
+                }
+
+                gva_main_progress_bar_set_fraction (0.0);
+
+                if (!gva_main_analyze_roms (&error))
+                {
+                        gva_error_handle (&error);
+                        return;
+                }
+
+                gva_main_progress_bar_hide ();
+        }
+        else if (gva_audit_detect_changes ())
+        {
+                gva_main_progress_bar_show ();
+
+                if (!gva_main_analyze_roms (&error))
+                {
+                        gva_error_handle (&error);
+                        return;
+                }
+
+                gva_main_progress_bar_hide ();
         }
 
+        /* Do this after ROMs are analyzed. */
+        if (!gva_main_init_search_completion (&error))
+        {
+                gva_error_handle (&error);
+                return;
+        }        
+
+        gtk_action_set_sensitive (GVA_ACTION_SEARCH, TRUE);
+        gtk_action_set_sensitive (GVA_ACTION_SHOW_CLONES, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_VIEW_AVAILABLE, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_VIEW_FAVORITES, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_VIEW_RESULTS, TRUE);
@@ -104,6 +191,9 @@ start (void)
                 gva_tree_view_update (&error);
                 gva_error_handle (&error);
         }
+
+        /* Present a helpful dialog if no ROMs were found. */
+        warn_if_no_roms ();
 }
 
 gint
@@ -113,6 +203,7 @@ main (gint argc, gchar **argv)
         GnomeProgram *program;
         GOptionContext *context;
 #endif
+        gchar *path;
         GError *error = NULL;
 
         g_thread_init (NULL);
@@ -138,6 +229,16 @@ main (gint argc, gchar **argv)
                 g_error ("%s", error->message);
 #endif
 
+        /* Change the working directory to that of the MAME executable.
+         * Why?  Because SDLMAME's default configuration uses relative
+         * search paths such as "rompath = roms".  The paths are relative
+         * to the directory containing the MAME executable, so we must run
+         * from that directory in order for SDLMAME's default configuration
+         * to work.  Annoying, but a common problem for users. */
+        path = g_path_get_dirname (MAME_PROGRAM);
+        g_chdir (path);
+        g_free (path);
+
         if (opt_inspect != NULL)
         {
                 gchar *value;
@@ -167,7 +268,7 @@ main (gint argc, gchar **argv)
                 g_print ("%s\n", MAME_PROGRAM);
                 exit (0);
         }
-        
+
         gtk_window_set_default_icon_name (PACKAGE);
 
         if (!gva_db_init (&error))
@@ -178,12 +279,15 @@ main (gint argc, gchar **argv)
         gva_play_back_init ();
         gva_preferences_init ();
         gva_properties_init ();
-        gva_search_init ();
 
-#ifdef HISTORY_FILE
+        gva_categories_init (&error);
+        gva_error_handle (&error);
+
         gva_history_init (&error);
         gva_error_handle (&error);
-#endif
+
+        gva_nplayers_init (&error);
+        gva_error_handle (&error);
 
         gtk_init_add ((GtkFunction) start, NULL);
 
